@@ -2,7 +2,7 @@ package Thread::Queue::Any::Monitored;
 
 # initializations
 @ISA=     qw( Thread::Queue::Any );
-$VERSION= '0.11';
+$VERSION= '0.12';
 
 # be as strict as possible
 use strict;
@@ -63,43 +63,67 @@ sub self { $SELF } #self
 
 sub _monitor {
     my $queue= $SELF= shift;
-    threads->self->detach if !shift;
+    threads->self->detach
+      if !shift;
     my $monitor= shift;
     my $exit=    shift;
 
     # execute any pre code
     my $post= shift || sub {};
     my $pre=  shift;
-    $pre->( @_ ) if $pre;
+    $pre->( @_ )
+      if $pre;
 
-    # processing
+    # exit value is a defined value
     my @value;
-    while (1) {
+    if ( defined($exit) ) {
+        while (1) {
 
-        # get values from the queue
-        {
-            lock( @{$queue} );
-            threads::shared::cond_wait @{$queue} until @{$queue};
-            @value=    @{$queue};
-            @{$queue}= ();
+            # get values from the queue
+            {
+                lock( @{$queue} );
+                threads::shared::cond_wait @{$queue} until @{$queue};
+                @value=    @{$queue};
+                @{$queue}= ();
+            }
+
+            # process all queue elements
+            foreach my $value (@value) {
+        	    my @set= @{ Storable::thaw($value) };
+
+                # we're done
+                return $post->(@_)
+                  if $set[0] eq $exit;
+
+                # continue monitoring
+                $monitor->(@set);
+            }
         }
+    }
 
-        # process all queue elements
-        foreach my $value (@value) {
-	    my @set= @{ Storable::thaw($value) };
+    # exit value is undef
+    else {
+        while (1) {
 
-            # we're done by specific exit code
-            if ( defined($exit) ) {
-                return $post->(@_) if $set[0] eq $exit;
+            # get values from the queue
+            {
+                lock( @{$queue} );
+                threads::shared::cond_wait @{$queue} until @{$queue};
+                @value=    @{$queue};
+                @{$queue}= ();
             }
 
-            # we're done without specific exit code
-            elsif ( !defined( $set[0] ) ) {
-                return $post->(@_);
-            }
+            # process all queue elements
+            foreach my $value (@value) {
+        	    my @set= @{ Storable::thaw($value) };
 
-            # continue monitoring
-            $monitor->(@set);
+                # we're done
+                return $post->(@_)
+                  if !defined( $set[0] );
+
+                # continue monitoring
+                $monitor->(@set);
+            }
         }
     }
 } #_monitor
@@ -132,7 +156,7 @@ Thread::Queue::Any::Monitored - monitor a queue for any specific content
 
 =head1 VERSION
 
-This documentation describes version 0.11.
+This documentation describes version 0.12.
 
 =head1 DESCRIPTION
 
